import { PropType, defineComponent } from 'vue';
import styles from './index.module.less';
import { NButton, NEllipsis, NSpace, NImage, NTag, useDialog } from 'naive-ui';
import pTag from './images/p-tag.svg';
import eTag from './images/e-tag.svg';
import pEdit from './images/p-edit.svg';
import eEdit from './images/e-edit.svg';
import iconPause from './images/icon-pause.svg';
import pDelete from './images/p-delete.svg';
import eDelete from './images/e-delete.svg';
import iconDelete from './images/icon-delete.png';
import { useUserStore } from '/src/store/modules/users';
type ItemType = {
  id: string | number;
  trainingType: 'PRACTICE' | 'EVALUATION';
  musicId: string | number;
  coverImg: string;
  musicName: string;
  typeList: string[];
};

export default defineComponent({
  name: 'train-type',
  props: {
    type: {
      type: String as PropType<'prepare' | 'homework'>,
      default: 'homework'
    },
    item: {
      type: Object as PropType<ItemType>,
      default: () => ({})
    },
    isDelete: {
      type: Boolean,
      default: false
    }
  },
  emits: ['click', 'delete', 'edit'],
  setup(props, { emit }) {
    const userStore = useUserStore();
    const dialog = useDialog();

    const onDelete = () => {
      const dialogT = dialog.warning({
        title: '提示',
        content: '您确定是否删除？',
        positiveText: '确定',
        negativeText: '取消',
        onPositiveClick: () => {
          dialogT.loading = true;
          emit('delete', props.item);
        }
      });
    };

    const onDetail = () => {
      const origin = /(localhost|192)/.test(location.host)
        ? 'https://dev.kt.colexiu.com'
        : location.origin;
      const src = `${origin}/instrument?platform=pc&modelType=practise`;
      window.open(src, '_blank');
    };
    return () => (
      <div
        class={[
          styles.trainType,
          props.item.trainingType === 'EVALUATION' ? styles.evaluationType : ''
        ]}
        onClick={() => emit('click', props.item)}>
        {props.isDelete && <div class={styles.overflowBg}></div>}
        <div class={styles['train-header']}>
          <div class={styles.title}>
            <img
              src={props.item.trainingType === 'EVALUATION' ? eTag : pTag}
              class={styles['title-tag']}
            />
            <NEllipsis class={styles['title-text']} tooltip={false}>
              {props.item.musicName}
            </NEllipsis>
          </div>

          {props.isDelete ? (
            <NButton
              class={styles.iconDelete}
              quaternary
              round
              onClick={(e: MouseEvent) => {
                e.stopPropagation();
                emit('delete', props.item);
              }}>
              <img src={iconDelete} />
            </NButton>
          ) : (
            <NButton class={styles.btn} round onClick={onDetail}>
              {props.item.trainingType === 'EVALUATION'
                ? '评测模式'
                : '练习模式'}
              <img src={iconPause} />
            </NButton>
          )}
        </div>
        <div class={styles['train-content']}>
          <NImage src={props.item.coverImg} previewDisabled objectFit="cover" />
          <div class={styles.preview}>
            <NButton
              strong
              secondary
              class={styles.previewBtn}
              onClick={onDetail}>
              预览
            </NButton>
          </div>
        </div>
        <div class={styles['train-footer']}>
          <NSpace class={styles.type}>
            {props.item.typeList?.map((type: string) => (
              <NTag>{type}</NTag>
            ))}
          </NSpace>

          <NSpace size={6}>
            <n-button
              quaternary
              disabled={props.isDelete}
              class={styles.operation}
              onClick={(e: MouseEvent) => {
                e.stopPropagation();
                emit('edit', props.item);
              }}>
              <img
                src={props.item.trainingType === 'EVALUATION' ? eEdit : pEdit}
              />
            </n-button>
            {props.type === 'homework' && (
              <n-button
                quaternary
                disabled={props.isDelete}
                class={styles.operation}
                onClick={(e: MouseEvent) => {
                  e.stopPropagation();
                  onDelete();
                }}>
                <img
                  src={
                    props.item.trainingType === 'EVALUATION' ? eDelete : pDelete
                  }
                />
              </n-button>
            )}
          </NSpace>
        </div>
      </div>
    );
  }
});
